// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.wpilibj.shuffleboard.BuiltInWidgets;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.constants.OIConstants;
import frc.robot.subsystems.Drivetrain;
import frc.robot.subsystems.Flicker;
import frc.robot.subsystems.Shooter;

public class RobotContainer {
  private Flicker flicker;
  private Shooter shooter;
  
  private Drivetrain drivetrain;
  
  private CommandXboxController driver;
  public RobotContainer() {
    //sets up controllers
    drivetrain = new Drivetrain();
    flicker = new Flicker();
    driver = new CommandXboxController(OIConstants.kDriverUSB); 

    configureBindings();
    configureShuffleboard();
  }

  private void configureBindings() {
    //manual controls for driving
    drivetrain.setDefaultCommand(
      drivetrain.driveArcade(
        driver::getLeftY, 
        driver::getLeftX 
      )
    );  
    
    flicker.setDefaultCommand(flicker.stop());
    //manual controls for shooter and flicker
    
    driver.a().whileTrue(flicker.setSpeed(() ->1 ));
    
    shooter.setDefaultCommand(shooter.stop());
    
    driver.rightBumper().whileTrue(shooter.setSpeed(() -> 1)); 
  }
  private void configureShuffleboard() {
    //sets up the widget for the shuffboard
    ShuffleboardTab robotIndicatorTab = Shuffleboard.getTab(OIConstants.kRobotIndicatorsTabName);
    
    robotIndicatorTab.addBoolean("Frisbee Presence Sensor", flicker::frisbeeSensor)
    .withPosition(0, 0)
    .withSize(2, 1)
    .withWidget(BuiltInWidgets.kBooleanBox); 
    
  }
    
  public Command getAutonomousCommand() {
    //sets up the autonomous command, it drives forward for 2 seconds, spins the shooter mototrs for 1 second, and both shooter and flicker for 3 seconds.
    return drivetrain.driveTank(() -> .5,() -> .5).withTimeout(2).andThen(
      shooter.setSpeed(()-> 1).withTimeout(1), 
      shooter.setSpeed(()->1).alongWith(flicker.setSpeed(()->1))
      .withTimeout(3)
    );
  }
}
